@@ -19,17 +19,19 @@
 #include <kplotobject.h>
 
 #include <klocale.h>
-#include <kdebug.h>
 #include <kactioncollection.h>
 #include <kstandardaction.h>
 #include <ktoolinvocation.h>
 #include <kunitconversion/converter.h>
 #include "prefs.h"
+#include <KConfig>
+#include <KConfigWidgets/khelpclient.h>
 
 //QT-Includes
 #include <QKeyEvent>
 #include <QPen>
 #include <QTimer>
+#include <QDebug>
 
 AxisData::AxisData(AXISTYPE type) : currentDataType(-1)
 {
@@ -104,7 +106,7 @@ ElementDataViewer::~ElementDataViewer()
 
 void ElementDataViewer::slotHelp()
 {
-    KToolInvocation::invokeHelp("plot_data", "kalzium");
+    KHelpClient::invokeHelp("plot_data", "kalzium");
 }
 
 void ElementDataViewer::rangeChanged()
@@ -126,14 +128,14 @@ void ElementDataViewer::fullRange()
 
 void ElementDataViewer::setLimits()
 {
-    kDebug() << "ElementDataViewer::setLimits()";
+    qDebug() << "ElementDataViewer::setLimits()";
 
     double x1 = 0.0, x2 = 0.0, y1 = 0.0, y2 = 0.0;
 
     getMinMax(x1, x2, m_xData);
     getMinMax(y1, y2, m_yData);
 
-    kDebug() << x1 << " :: " << x2 << " ----- "  << y1 << " :: " << y2;
+    qDebug() << x1 << " :: " << x2 << " ----- "  << y1 << " :: " << y2;
 
     //JH: add some padding to show all points
     double dx = 0.05*(x2-x1);
@@ -163,7 +165,7 @@ void ElementDataViewer::getMinMax(double& min, double& max, AxisData * data)
     double minValue = data->value(firstElement);
     double maxValue = data->value(firstElement);
 
-    kDebug() << "Taking elements from " << firstElement << " to " << lastElement;
+    qDebug() << "Taking elements from " << firstElement << " to " << lastElement;
 
     for (int _currentVal = firstElement; _currentVal <= lastElement; ++_currentVal) { //go over all selected elements
         double v = data->value(_currentVal);
@@ -176,7 +178,7 @@ void ElementDataViewer::getMinMax(double& min, double& max, AxisData * data)
         }
     }
 
-    kDebug() << "The value are ]"<< minValue << " , " << maxValue << "[.";
+    qDebug() << "The value are ]"<< minValue << " , " << maxValue << "[.";
 
     min = minValue;
     max = maxValue;
@@ -530,4 +532,3 @@ void ElementDataViewer::initData()
     setupAxisData(m_yData);
 }
 
-#include "elementdataviewer.moc"
